Ansible Runner
==============

[![PyPi](https://img.shields.io/pypi/v/ansible-runner.svg?logo=Python)](https://pypi.org/project/ansible-runner/)
[![Documentation](https://readthedocs.org/projects/ansible-runner/badge/?version=stable)](https://ansible-runner.readthedocs.io/en/latest/)
[![Code of Conduct](https://img.shields.io/badge/Code%20of%20Conduct-Ansible-silver.svg)](https://docs.ansible.com/ansible/latest/community/code_of_conduct.html)
[![Ansible Mailing lists](https://img.shields.io/badge/Mailing%20lists-Ansible-orange.svg)](https://docs.ansible.com/ansible/latest/community/communication.html#mailing-list-information)
[![codecov](https://codecov.io/gh/ansible/ansible-runner/branch/devel/graph/badge.svg?token=CmCcjBz0pQ)](https://codecov.io/gh/ansible/ansible-runner)

Ansible Runner is a tool and Python library that helps when interfacing with Ansible directly or as part of another system. Ansible Runner works as a standalone tool, a container image interface, or a Python module that can be imported. The goal is to provide a stable and consistent interface abstraction to Ansible.

See the [latest documentation] for usage details.

Get Involved
============

* [GitHub issues] to track bug report and feature ideas
* [GitHub Milestones] to track what's for the next release
* Want to contribute? Please check out our [contributing guide]
* Join us in the `#ansible-runner` channel on Libera.chat IRC
* Join the discussion in [`#awx-project`][irc]
* For the full list of Ansible email Lists, IRC channels see the [Ansible Mailing lists].

[GitHub issues]: https://github.com/ansible/ansible-runner/issues
[GitHub Milestones]: https://github.com/ansible/ansible-runner/milestones
[contributing guide]: https://github.com/ansible/ansible-runner/blob/devel/CONTRIBUTING.md
[irc]: https://groups.google.com/forum/#!forum/awx-project
[Ansible Mailing lists]: https://docs.ansible.com/ansible/latest/community/communication.html#mailing-list-information
[latest documentation]: https://ansible-runner.readthedocs.io/en/latest/
